@@ -486,4 +486,9 @@ class GQLHandler(HandlerGQL):
             "verifyEmailOrPhoneCode",
         )
 
+    async def deleteMessageFromApp(self, wuid: str, msgId: str) -> dict[str, Any]:
+        return self.runAuthorizedGqlQuery(
+            gm.WATCH_M.get("deleteChatMessageM", ""), {"uid": wuid, "msgId": msgId}, "DeleteChatMessage"
+        ).get("data", {})
+
     ########## SECTION MUTATION end ##########
