@@ -10,7 +10,7 @@ from .exception_classes import Error, ErrorMSG, LoginError, NoAdminError, PhoneO
 from .gql_handler import GQLHandler
 from .model import Chats, ChatsNew, SimpleChat
 from .pyxplora import PyXplora
-from .status import LocationType, NormalStatus, UserContactType, WatchOnlineStatus
+from .status import Emoji, LocationType, NormalStatus, UserContactType, WatchOnlineStatus
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -313,7 +313,9 @@ class PyXploraApi(PyXplora):
         # bug?
         return (self._gqlHandler.unReadChatMsgCount(wuid)).get("unReadChatMsgCount", -1)
 
-    def getWatchChats(self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "") -> list[dict[str, Any]]:
+    def getWatchChats(
+        self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "", show_del_msg: bool = True
+    ) -> list[dict[str, Any]]:
         retryCounter = 0
         dataOk: list[dict[str, Any]] = []
         chats: list[dict[str, Any]] = []
@@ -321,7 +323,7 @@ class PyXploraApi(PyXplora):
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             try:
-                _chatsNew: ChatsNew = Chats.from_dict(self.getWatchChatsRaw(wuid, offset, limit, msgId)).chatsNew
+                _chatsNew: ChatsNew = ChatsNew.from_dict(self.getWatchChatsRaw(wuid, offset, limit, msgId, show_del_msg))
                 _list: list[SimpleChat] = _chatsNew.list
                 if not _chatsNew or not _list:
                     return chats
@@ -347,14 +349,26 @@ class PyXploraApi(PyXplora):
                 self.delay(self.retryDelay)
         return chats
 
-    def getWatchChatsRaw(self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "") -> list[dict[str, Any]]:
+    def getWatchChatsRaw(
+        self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "", show_del_msg: bool = True
+    ) -> list[dict[str, Any]]:
         retryCounter = 0
         dataOk: dict[str, Any] = []
         _chatsNew: dict[str, Any] = {}
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             try:
-                _chatsNew = self._gqlHandler.chats(wuid, offset, limit, msgId)
+                chats: Chats = Chats.from_dict(self._gqlHandler.chats(wuid, offset, limit, msgId))
+
+                oldChatList: list[SimpleChat] = chats.chatsNew.list
+                newChatList: list[SimpleChat] = []
+                for chat in oldChatList:
+                    chat.data.emoticon_id = Emoji["M%s" % chat.data.emoticon_id].value
+                    if show_del_msg:
+                        newChatList.append(chat)
+                    elif chat.data.delete_flag == 0:
+                        newChatList.append(chat)
+                _chatsNew = ChatsNew(newChatList).to_dict()
             except Error as error:
                 _LOGGER.debug(error)
             dataOk = _chatsNew
@@ -704,3 +718,9 @@ class PyXploraApi(PyXplora):
     ) -> dict[str, Any]:
         data = self._gqlHandler.modifyContact(contactId, isAdmin, contactName, fileId)
         return data
+
+    def deleteMessageFromApp(self, wuid: str, msgId: str) -> bool:
+        data = self._gqlHandler.deleteMessageFromApp(wuid, msgId)
+        if data.get("deleteMsg", False):
+            return True
+        return False
