@@ -11,7 +11,7 @@ from .exception_classes import Error, ErrorMSG, LoginError, NoAdminError
 from .gql_handler_async import GQLHandler
 from .model import Chats, ChatsNew, SimpleChat
 from .pyxplora import PyXplora
-from .status import LocationType, NormalStatus, UserContactType, WatchOnlineStatus
+from .status import Emoji, LocationType, NormalStatus, UserContactType, WatchOnlineStatus
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -309,7 +309,9 @@ class PyXploraApi(PyXplora):
         # bug?
         return (await self._gqlHandler.unReadChatMsgCount_a(wuid)).get("unReadChatMsgCount", -1)
 
-    async def getWatchChats(self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "") -> list[dict[str, Any]]:
+    async def getWatchChats(
+        self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "", show_del_msg: bool = True
+    ) -> list[dict[str, Any]]:
         retryCounter = 0
         dataOk: list[dict[str, Any]] = []
         chats: list[dict[str, Any]] = []
@@ -317,7 +319,7 @@ class PyXploraApi(PyXplora):
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             try:
-                _chatsNew: ChatsNew = Chats.from_dict(await self.getWatchChatsRaw(wuid, offset, limit, msgId)).chatsNew
+                _chatsNew: ChatsNew = ChatsNew.from_dict(await self.getWatchChatsRaw(wuid, offset, limit, msgId, show_del_msg))
                 _list: list[SimpleChat] = _chatsNew.list
                 if not _chatsNew or not _list:
                     return chats
@@ -343,14 +345,26 @@ class PyXploraApi(PyXplora):
                 await sleep(self.retryDelay)
         return chats
 
-    async def getWatchChatsRaw(self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "") -> dict[str, Any]:
+    async def getWatchChatsRaw(
+        self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "", show_del_msg: bool = True
+    ) -> dict[str, Any]:
         retryCounter = 0
         dataOk: dict[str, Any] = []
         _chatsNew: dict[str, Any] = {}
         while not dataOk and (retryCounter < self.maxRetries + 2):
             retryCounter += 1
             try:
-                _chatsNew = await self._gqlHandler.chats_a(wuid, offset, limit, msgId)
+                chats: Chats = Chats.from_dict(await self._gqlHandler.chats_a(wuid, offset, limit, msgId))
+
+                oldChatList: list[SimpleChat] = chats.chatsNew.list
+                newChatList: list[SimpleChat] = []
+                for chat in oldChatList:
+                    chat.data.emoticon_id = Emoji["M%s" % chat.data.emoticon_id].value
+                    if show_del_msg:
+                        newChatList.append(chat)
+                    elif chat.data.delete_flag == 0:
+                        newChatList.append(chat)
+                _chatsNew = ChatsNew(newChatList).to_dict()
             except Error as error:
                 _LOGGER.debug(error)
             dataOk = _chatsNew
@@ -694,3 +708,9 @@ class PyXploraApi(PyXplora):
     async def modifyContact(self, contactId: str, isAdmin: bool, contactName: str = "", fileId: str = "") -> dict[str, Any]:
         data = await self._gqlHandler.modifyContact_a(contactId, isAdmin, contactName, fileId)
         return data
+
+    async def deleteMessageFromApp(self, wuid: str, msgId: str) -> bool:
+        data = await self._gqlHandler.deleteMessageFromApp_a(wuid, msgId)
+        if data.get("deleteMsg", False):
+            return True
+        return False
